@@ -40,7 +40,7 @@ test_that("edl_download via token", {
 
 
 
-test_that("edl_download, netrc+curl", {
+test_that("edl_download, netrc+libcurl", {
 
   skip_on_cran()
   skip_if_offline()
@@ -50,7 +50,7 @@ test_that("edl_download, netrc+curl", {
   url <- lpdacc_example_url()
   f <- tempfile(fileext = ".tif")
 
-  edl_download(url, f, auth = "netrc", method = "curl", quiet = TRUE)
+  edl_download(url, f, auth = "netrc", method = "httr", quiet = TRUE)
 
   expect_true(file.exists(f))
   r <- terra::rast(f)
